@@ -54,7 +54,7 @@ def create_prospect_report(data, quarter_name, output_path):
     full_details_df["Ticker_Count"] = full_details_df["filer_name"].apply(lambda x: ticker_count[x]["total"])
     full_details_df = full_details_df[["filer_name","stock_name","stock_ticker","security_type","current_mv","current_percent_of_portfolio","source_date","sector","industry","AUM","NPD_Ticker","stock_holding_morethan1pct","Ticker_Count"]]
     
-    writer = pd.ExcelWriter("{output_path}ProspectReport_{quarter}.xlsx".format(output_path=output_path, quarter=quarter_name.replace("/","-")), engine="xlsxwriter")
+    writer = pd.ExcelWriter("{output_path}Prospect_Report_{quarter}.xlsx".format(output_path=output_path, quarter=quarter_name.replace("/","-")), engine="xlsxwriter")
     target_list_df.to_excel(writer, index=False, sheet_name="1_target_list")
     full_details_df.to_excel(writer, index=False, sheet_name="2_full_details")
     workbook = writer.book
@@ -105,7 +105,7 @@ def create_client_report(data, npd_tickers, npd_clients, quarter_name, output_pa
     #data = data.merge(npd_tickers[["stock_ticker","stock_name","sector","industry"]], on=["stock_ticker"])
     data = data[["filer_name","stock_name","stock_ticker","security_type","shares_change","position_change_type","avg_price","current_mv","current_percent_of_portfolio","source_date","sector","industry","AUM","NPD_Ticker"]]
 
-    writer = pd.ExcelWriter("{output_path}ClientReport_{quarter}.xlsx".format(output_path=output_path, quarter=quarter_name.replace("/","-")), engine="xlsxwriter")
+    writer = pd.ExcelWriter("{output_path}Client_Report_{quarter}.xlsx".format(output_path=output_path, quarter=quarter_name.replace("/","-")), engine="xlsxwriter")
     ticker_type_df_sorted.to_excel(writer, index=False, sheet_name="summary_ticker_type")
     pd.DataFrame().to_excel(writer, index=False, sheet_name="Holdings_Chart_Current_Qtr")
     npd_clients.to_excel(writer, index=False, sheet_name="Clients_by_AccountManager")
